package com.bwie.domain;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.bwie.domain.request.UserReq;
import com.bwie.utils.IdUtils;
import com.bwie.utils.SecurityUtils;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

@Data //lombok
@Builder
@NoArgsConstructor  //无参构造
@AllArgsConstructor //全参构造
@TableName(value = "user")
public class User {

    /**
     * 用户ID,主键自增
     */
    @TableId(type = IdType.AUTO)
    private Long userId;

    /**
     * 用户姓名
     */
    @TableField(value = "user_name")
    private String userName;

    /**
     * 用户电话
     */
    @TableField(value = "user_phone")
    private String userPhone;

    /**
     * 用户密码
     */
    @TableField(value = "user_pwd")
    private String userPwd;

    /**
     * 用户头像
     */
    @TableField(value = "user_pic")
    private String userPic;

    /**
     * 用户角色
     */
    @TableField(value = "user_roal")
    private Long userRoal;


    //加盐字段
    @TableField(exist = false)
    private String salt;

    //当前页
    @TableField(exist = false)
    private Integer pageNum=1;

    //当前页面条数
    @TableField(exist = false)
    private Integer pageSize=10;

    /**
     * 构建User添加对象方法
     * 加盐
     */
    public static User addBuilder(UserReq userReq){
        String salt = IdUtils.genId();//生成一个随机的盐值
        String passwordsalt = SecurityUtils.encryptPassword(userReq.getUserPwd(), salt);//工具类实现加盐加密
        return User.builder()
                .userName(userReq.getUserName())
                .userPwd(passwordsalt)
                .userPhone(userReq.getUserPhone())
                .userPic(userReq.getUserPic())
                .userRoal(userReq.getUserRoal().longValue())
                .salt(salt)
                .build();
    }

    /**
     * 构建User对象修改方法
     */
    public static User updateUser(UserReq userReq){
        return User.builder()
                .userId(userReq.getUserId().longValue())
                .userName(userReq.getUserName())
                .userPwd(userReq.getUserPwd())
                .userPhone(userReq.getUserPhone())
                .userPic(userReq.getUserPic())
                .build();
    }
}
